@@ -341,7 +341,7 @@
 #'
 #' @examples
 #'
-#' \donttest{
+#' \dontrun{
 #' # Surrogacy model evaluation performance study based on 10 generated data
 #' # (Computation takes around 20 minutes using a processor including 40
 #' # cores and a read only memory of 378 Go)
@@ -352,7 +352,7 @@
 #' joint.simul <- jointSurroPenalSimul(nb.dataset = 10, nbSubSimul= 600,
 #'                    ntrialSimul = 30, LIMparam = 0.001, LIMlogl = 0.001,
 #'                    LIMderiv = 0.001, nb.mc = 200, nb.gh = 20,
-#'                    nb.gh2 = 32, true.init.val = 1, print.iter = F, pfs = 0)
+#'                    nb.gh2 = 32, true.init.val = 1, print.iter = FALSE, pfs = 0)
 #'
 #' # results
 #' summary(joint.simul, d = 3, R2boot = 1) # bootstrap
@@ -364,7 +364,7 @@
 #'                    ntrialSimul = 30, nb.mc = 1000, type.joint.estim = 3,
 #'                    typecopula = 1, type.joint.simul = 3, theta.copula = 3,
 #'                    time.cens = 349, true.init.val = 1, R2 = 0.81, maxit = 40,
-#'                    print.iter = F)
+#'                    print.iter = FALSE)
 #'
 #' summary(joint.simul.cop.clay)
 #'
@@ -654,7 +654,7 @@ jointSurroPenalSimul = function(maxit = 40, indicator.zeta = 1, indicator.alpha
                                      n_node = n.knots, adjust_S = 1, adjust_T = 1, kapp_0 = 0,
                                      print.times = print.iter)
       # I deleate the created text file
-      file.remove(dir(pattern="kappa_valid_crois.txt"))
+      #file.remove(dir(pattern="kappa_valid_crois.txt"))
     }
 
     if(!is.null(kappa0) & (n_sim1 == 1)){
