@@ -18,19 +18,20 @@ contains
     
     use var_surrogate, only: posind_i, alpha_ui, const_res4, const_res5, res2_dcs_sujet,res2s_sujet, &
         theta_copule, delta, deltastar, copula_function, methodInt, pi, gamma_ui, determinant, &
-        varcovinv, adaptative, control_affichage
+        varcovinv, adaptative!, control_affichage
     use comon, only: ve
     
     IMPLICIT NONE
-    integer,intent(in):: ig, nsujet_trial
+    integer,intent(in):: ig, nsujet_trial 
     double precision,intent(in)::vsi,vti,ui
-    integer::j,n
+    integer::j,ig2!,n
     double precision::integrant, f_Sij, f_Tij, fbar_Sij, fbar_Tij, C_theta, phimun_S, phimun_T,phiprim_ST,&
                       sumphimun_ST, phisecond_ST, phiprimphimun_S, derivphi_ij, contri_indiv,phiprimphimun_T,&
                       f_V, tempon, logfbar_Sij, logfbar_Tij
     double precision, dimension(:,:),allocatable::m1,m3  
     double precision, dimension(:,:),allocatable::m    
-     
+    Integrant_Copula = 0.d0 
+    ig2=ig
     C_theta = 0.d0
     phimun_S = 0.d0
     phimun_T = 0.d0
@@ -544,11 +545,11 @@ contains
     !double precision::ca,cb,dd
     !double precision::res
     !double precision, dimension(2)::k0
-!    double precision, dimension(1)::v,b
+    !double precision, dimension(1)::v,b
     !double precision, dimension(2)::b_i      ! pour les 2 parametres des effets aleatoires a predire niveau essai
     !double precision, dimension(2,2)::v_i    ! pour les 2 parametres des effets aleatoires a predire niveau essai
     !double precision, allocatable, dimension(:,:)::H_hessOut,HIH,HIHOut,IH,invBi_chol
-
+    Integrale_Individuel = 0.d0 
     if(adaptative .and. switch_adaptative==1) then ! on effectue le changement de variable 
         xx=ui_chap(posind_i-1+j,1)+dsqrt(2.d0)*xx1*invBi_chol_Individuel(posind_i-1+j)            
         !!print*,"posind_i-1+j",posind_i-1+j
@@ -637,7 +638,7 @@ contains
     double precision, dimension(:,:),allocatable::m1,m3
     double precision, dimension(:,:),allocatable::m
     integer ::ii,jj,npg
-    double precision::ss1,auxfunca,ss,wsij,wtij,test,rho,ss2
+    double precision::ss1,auxfunca,ss,wsij,wtij,test,rho
     double precision, dimension(ndim)::xxl !vecteur qui contiendra à chaque fois les points de quadrature
     double precision,dimension(ndim,ndim)::invBi_chol_Essai_k ! pour recuperer les matrice B_k dans le vecteur des matrices B des essais K
 
@@ -657,6 +658,13 @@ contains
     ! !print*,"vti",vti
     allocate(m(1,1))    
     allocate(m1(1,2),m3(1,2))
+
+    if(.false.) then 
+        varcov=varcov
+        test=test 
+        rho=rho  
+        invBi_chol_Essai_k = invBi_chol_Essai_k
+    end if 
     ! !print*,"matrice varcovinv=",varcovinv
     ! !print*,"matrice m1=",m1
     ! !print*,"matrice m3=",m3
@@ -685,11 +693,10 @@ contains
     auxfunca=0.d0
     ss=0.d0
     ss1=0.d0
-    ss2=0.d0
     !$OMP PARALLEL DO default(none) PRIVATE (ii,jj,xxl,wsij,wtij,m1,m3,m) firstprivate(ss1,auxfunca,vsi,vti,ui,uti)& 
     !$OMP SHARED(npg,varcovinv,nnodes,xx1,ww1,invBi_chol_Essai_k,ndim,adaptative,posind_i,test,rho,varcov,&
     !$OMP delta,j,deltastar,const_res4,ve,const_res5)&
-    !$OMPREDUCTION(+:ss2) SCHEDULE(Dynamic,1)
+    !$OMPREDUCTION(+:ss) SCHEDULE(Dynamic,1)
         do ii=1,npg
             ss1=0.d0
             do jj=1,npg
@@ -727,12 +734,10 @@ contains
                 ! !print*,"Integrant niveau Individuel=",auxfunca
                 ! stop
             end do
-            ss2 = ss2+ww1(ii)*ss1
+            ss = ss+ww1(ii)*ss1
         end do
     !$OMP END PARALLEL DO
     
-    ss = ss2
-    
     if(adaptative) then
         ! if(frailt_base==0) ss=ss*2.d0**(dble(ndim)/2.d0)*invBi_cholDet_Essai(i)  ! en admettant que "invBi_cholDet_Essai" c'est bien pour les individus
     end if
@@ -886,12 +891,14 @@ contains
         IMPLICIT NONE
         integer,intent(in):: j,nsimu,ndim
         double precision,intent(in)::vsi,vti,ui,uti
-        double precision, intent(in)::mu1
+        double precision, intent(in)::mu1 
+        double precision::mu12
         double precision,dimension(nsimu,ndim),intent(in)::frailij
         !double precision,dimension(:,:),allocatable::usim
         integer::n !l
         
-        
+        mu12=mu1
+        Integrale_Individuel_MC_cor = 0.d0 
         ! Je calcule pour chaque individu du cluster par vectorisation son integrale par gaussHermite non adaptative
         if(ndim==2)then
             !allocate(usim(1:nsimu,ndim))
@@ -1206,13 +1213,14 @@ contains
     double precision,dimension(:),allocatable ::xx1,ww1
     double precision::resultat,inc
     !double precision, external::gaussHermMultMC    
-    
+    npoint = npoint
     allocate(xx1(npoint))
     allocate(ww1(npoint))
-    
     nnodes=npoint
-    !!print*,"npoint=",npoint
-    
+    !!print*,"npoint=",npoint 
+    frailst = 0.d0 
+    xx1 = 0.d0 
+    ww1 = 0.d0 
     if(nnodes.eq.5) then
       xx1(1:nnodes) = x5(1:nnodes)
       ww1(1:nnodes) = w5(1:nnodes)
@@ -1231,6 +1239,9 @@ contains
     else if (nnodes.eq.20) then
       xx1(1:nnodes) = x2(1:nnodes)
       ww1(1:nnodes) = w2(1:nnodes)
+    else 
+      xx1(1:nnodes) = 0.0d0 
+      ww1(1:nnodes) = 0.0d0
     end if
     
     !integration sur vsi et vti
@@ -1632,4 +1643,4 @@ recursive function gaussHermMultMC(frail1,frail,i,k,x,w,inc) result(herm)
   
   end function funcJointSurroKendall
   
-end module fonction_A_integrer
+end module fonction_A_integrer
\ No newline at end of file
