@@ -399,6 +399,11 @@
     double precision::lam,lamdc,temp, tempscl
     double precision::logGammaJ
 
+    
+    su = 0.d0 
+    sut1 = 0.0d0 
+    sut0 = 0.d0 
+    sudc = 0.d0 
     n = 0
     betaR = 0.d0
     etaR = 0.d0
@@ -610,7 +615,10 @@
     etaR = 0.d0
     betaD = 0.d0
     etaD = 0.d0
-
+    sudc = 0.d0 
+    su = 0.0d0 
+    sut1 = 0.0d0 
+    sut0 = 0.0d0 
     theta = bh(np-nva-1)*bh(np-nva-1)
     alpha = bh(np-nva)
 
