@@ -5,7 +5,7 @@
     !use comon,only:cens,nbintervR,nbintervDC,ttt,tttdc
     use comon,only:t0,t1,t0dc,t1dc,c,cdc,nsujet,nva,nva1,nva2,&
     nst,effet,stra,ve,vedc,ng,g,nig,AG,indic_ALPHA,alpha,theta,auxig,aux1,aux2,res1,res3&
-    ,kkapa,betaR,etaR,betaD,etaD
+    ,kkapa,betaR,etaR,betaD,etaD,nb_gl
     use tailles
     use comongroup
     use residusM
@@ -278,7 +278,7 @@
         do ig=1,ng
             auxig=ig
             choix = 3
-            call gaulagJ(int,choix)
+            call gaulagJ(int,choix,nb_gl)
             integrale3(ig) = int !moins bon
 ! parfois quand bcp de deces par groupe integrale3=0
 !            if(integrale3(ig).lt.1.d-300)then
