@@ -924,30 +924,35 @@ if(nmescur.eq.(-1)) then ! this is for the case where we have no repeated measur
         pe2 = 0.d0
     
         do i=1,n-3
-        if(effet.eq.1) then
-            pe1 = pe1+(the1(i-3)*the1(i-3)*m3m3(i))+(the1(i-2) &
-            *the1(i-2)*m2m2(i))+(the1(i-1)*the1(i-1)*m1m1(i))+( &
-            the1(i)*the1(i)*mmm(i))+(2.d0*the1(i-3)*the1(i-2)* &
-            m3m2(i))+(2.d0*the1(i-3)*the1(i-1)*m3m1(i))+(2.d0* &
-            the1(i-3)*the1(i)*m3m(i))+(2.d0*the1(i-2)*the1(i-1)* &
-            m2m1(i))+(2.d0*the1(i-2)*the1(i)*m2m(i))+(2.d0*the1(i-1) &
-            *the1(i)*m1m(i))
+            if(effet.eq.1) then
+              !trivariate model, need penalization for both terminal and recurrent times
+              pe1 = pe1+(the1(i-3)*the1(i-3)*m3m3(i))+(the1(i-2) &
+              *the1(i-2)*m2m2(i))+(the1(i-1)*the1(i-1)*m1m1(i))+( &
+              the1(i)*the1(i)*mmm(i))+(2.d0*the1(i-3)*the1(i-2)* &
+              m3m2(i))+(2.d0*the1(i-3)*the1(i-1)*m3m1(i))+(2.d0* &
+              the1(i-3)*the1(i)*m3m(i))+(2.d0*the1(i-2)*the1(i-1)* &
+              m2m1(i))+(2.d0*the1(i-2)*the1(i)*m2m(i))+(2.d0*the1(i-1) &
+              *the1(i)*m1m(i))
+    
+              pe2 = pe2+(the2(i-3)*the2(i-3)*m3m3(i))+(the2(i-2) &
+              *the2(i-2)*m2m2(i))+(the2(i-1)*the2(i-1)*m1m1(i))+( &
+              the2(i)*the2(i)*mmm(i))+(2.d0*the2(i-3)*the2(i-2)* &
+              m3m2(i))+(2.d0*the2(i-3)*the2(i-1)*m3m1(i))+(2.d0* &
+              the2(i-3)*the2(i)*m3m(i))+(2.d0*the2(i-2)*the2(i-1)* &
+              m2m1(i))+(2.d0*the2(i-2)*the2(i)*m2m(i))+(2.d0*the2(i-1) &
+              *the2(i)*m1m(i))
             else
-            pe1 = 0.d0
+              !joint model for longitudinal outcome with 1 single terminal time
+              !The baseline hazard function is stored in the vector the2
+              pe1 = 0.d0
+              pe2 = pe2+(the2(i-3)*the2(i-3)*m3m3(i))+(the2(i-2) &
+              *the2(i-2)*m2m2(i))+(the2(i-1)*the2(i-1)*m1m1(i))+( &
+              the2(i)*the2(i)*mmm(i))+(2.d0*the2(i-3)*the2(i-2)* &
+              m3m2(i))+(2.d0*the2(i-3)*the2(i-1)*m3m1(i))+(2.d0* &
+              the2(i-3)*the2(i)*m3m(i))+(2.d0*the2(i-2)*the2(i-1)* &
+              m2m1(i))+(2.d0*the2(i-2)*the2(i)*m2m(i))+(2.d0*the2(i-1) &
+              *the2(i)*m1m(i))
             end if
-            if(nst.eq.1)then
-                pe2=0.d0
-            else
-    
-                pe2 = pe2+(the2(i-3)*the2(i-3)*m3m3(i))+(the2(i-2) &
-                *the2(i-2)*m2m2(i))+(the2(i-1)*the2(i-1)*m1m1(i))+( &
-                the2(i)*the2(i)*mmm(i))+(2.d0*the2(i-3)*the2(i-2)* &
-                m3m2(i))+(2.d0*the2(i-3)*the2(i-1)*m3m1(i))+(2.d0* &
-                the2(i-3)*the2(i)*m3m(i))+(2.d0*the2(i-2)*the2(i-1)* &
-                m2m1(i))+(2.d0*the2(i-2)*the2(i)*m2m(i))+(2.d0*the2(i-1) &
-                *the2(i)*m1m(i))
-    
-            endif
         end do
     
         pe = k0(1)*pe1 + k0(2)*pe2
